@@ -16,7 +16,6 @@ import cssutils.helper
 import math
 import re
 import xml.dom
-import collections
 
 
 class CSSValue(cssutils.util._NewBase):
@@ -589,7 +588,7 @@ class CSSPrimitiveValue(CSSValue):
         val, type_ = self._value
         # try get by type_
         pt = self.__unitbytype.get(type_, 'CSS_UNKNOWN')
-        if isinstance(pt, collections.Callable):
+        if callable(pt):
             # multiple options, check value too
             pt = pt(val)
         self._primitiveType = getattr(self, pt)
