@@ -122,7 +122,7 @@ class CSSutilsTestCase(basetest.BaseTestCase):
         self.assertEqual(irs.cssText, '@import "../import3.css";\n@import "import-impossible.css" print;\n.import2 {\n    /* sheets/import2.css */\n    background: url(http://example.com/images/example.gif);\n    background: url(//example.com/images/example.gif);\n    background: url(/images/example.gif);\n    background: url(images2/example.gif);\n    background: url(./images2/example.gif);\n    background: url(../images/example.gif);\n    background: url(./../images/example.gif)\n    }'.encode())
 
         # next test
-        css = 'a:after { content: "羊蹄€\u2020" }'
+        css = 'a:after { content: "羊蹄€\\u2020" }'
 
         fd, name = tempfile.mkstemp('_cssutilstest.css')
         t = os.fdopen(fd, 'wb')
