@@ -7,6 +7,7 @@ TODO: old tests as new ones are **not complete**!
 import sys
 import xml.dom
 from . import basetest
+import cssutils.tokenize2 as tokenize2
 from cssutils.tokenize2 import *
 
 class TokenizerTestCase(basetest.BaseTestCase):
@@ -48,22 +49,24 @@ class TokenizerTestCase(basetest.BaseTestCase):
         r'\(': [('IDENT', r'\(', 1, 1)],
         r'\1 \22 \333 \4444 \55555 \666666 \777777 7 \7777777':
             [(
-                ('IDENT', '\x01"\u0333\u4444\U00055555\\666666 \\777777 7', 1, 1)
+                ('IDENT', '\x01"\\u0333\\u4444\\U00055555\\666666 \\777777 7', 1, 1)
                 if sys.maxunicode > 0x10000 else
-                ('IDENT', '\x01"\u0333\u4444\\55555 \\666666 \\777777 7', 1, 1)
+                ('IDENT', '\x01"\\u0333\\u4444\\55555 \\666666 \\777777 7', 1, 1)
             ),
             ('S', ' ', 1, 43),
             ('IDENT', '\\7777777', 1, 44)
         ],
+        # Not a function, important for media queries
+        'and(': [('IDENT', 'and', 1, 1), ('CHAR', '(', 1, 4)],
 
 
         '\\1 b': [('IDENT', '\x01b', 1, 1)],
         '\\44 b': [('IDENT', 'Db', 1, 1)],
-        '\\123 b': [('IDENT', '\u0123b', 1, 1)],
-        '\\1234 b': [('IDENT', '\u1234b', 1, 1)],
+        '\\123 b': [('IDENT', '\\u0123b', 1, 1)],
+        '\\1234 b': [('IDENT', '\\u1234b', 1, 1)],
         '\\12345 b':
             [(
-                ('IDENT', '\U00012345b', 1, 1)
+                ('IDENT', '\\U00012345b', 1, 1)
                 if sys.maxunicode > 0x10000 else
                 ('IDENT', '\\12345 b', 1, 1)
             )],
@@ -856,6 +859,31 @@ class TokenizerTestCase(basetest.BaseTestCase):
 #            self.assertRaises(exception, self.tokenizer.tokenize, css)
 
 
+class TokenizerUtilsTestCase(basetest.BaseTestCase, metaclass=basetest.GenerateTests):
+    """Tests for the util functions of tokenize"""
+
+    def gen_test_has_at(self, string, pos, text, expected):
+        self.assertEqual(tokenize2.has_at(string, pos, text), expected)
+    gen_test_has_at.cases = [
+        ('foo', 0, 'foo', True),
+        ('foo', 0, 'f', True),
+        ('foo', 1, 'o', True),
+        ('foo', 1, 'oo', True),
+        ('foo', 4, 'foo', False),
+        ('foo', 0, 'bar', False),
+        ('foo', 0, 'foobar', False),
+    ]
+
+    def gen_test_suffix_eq(self, string, pos, suffix, expected):
+        self.assertEqual(tokenize2.suffix_eq(string, pos, suffix), expected)
+    gen_test_suffix_eq.cases = [
+        ('foobar', 0, 'foobar', True),
+        ('foobar', 3, 'bar', True),
+        ('foobar', 3, 'foo', False),
+        ('foobar', 10, 'bar', False),
+    ]
+
+
 if __name__ == '__main__':
     import unittest
     unittest.main()
